@@ -46,6 +46,21 @@ void Status::ClearStatus()
   ip.clear();
 }
 
+int Status::GetQualityFromSignalNoiseDbm(int signal, int noise)
+{
+  int quality=signal-noise;
+
+  if (quality<0) {
+    return 0;
+  }
+  if (quality>=0 && quality<40) {
+    return 5*quality/2;
+  }
+  else {
+    return 100;
+  }
+}
+
 bool Status::UpdateStatus()
 {
   return false;
