@@ -33,12 +33,12 @@ extern "C" {
 #include <cstring>
 #include <cstdlib>
 #include <fstream>
+#include <iostream>
 
 #include <Lum/Base/String.h>
 
 #include <Lum/OS/Display.h>
 
-#include <iostream>
 bool StatusLinux::UpdateStatus()
 {
          std::ifstream file;
@@ -50,11 +50,14 @@ bool StatusLinux::UpdateStatus()
   struct iw_range      range;
          char          buffer[1024];
 
+  Lum::OS::Guard<Lum::OS::Mutex> guard(mutex);
+
   ClearStatus();
 
   file.open("/proc/net/wireless",std::ios::in);
 
   if (!file) {
+    std::cerr << "Cannot read /proc/net/wireless" << std::endl;
     return false;
   }
 
@@ -72,12 +75,14 @@ bool StatusLinux::UpdateStatus()
   file.close();
 
   if (interface.empty()) {
+    std::cerr << "Cannot find valid interface in /proc/net/wireless" << std::endl;
     return false;
   }
 
   handle=socket(AF_INET,SOCK_DGRAM,0);
 
   if (handle<0) {
+    std::cerr << "Cannot open socket:" << strerror(errno) << std::endl;
     return false;
   }
 
@@ -179,17 +184,28 @@ bool StatusLinux::UpdateStatus()
 
     if (ioctl(handle,SIOCGIWSTATS,&data)>=0) {
       if (!(IW_QUAL_QUAL_INVALID & data.u.data.flags)) {
-        maxQuality=range.max_qual.qual;
-        if (maxQuality<=0 || maxQuality>100) {
-          maxQuality=100;
-        }
-
-        //std::cout << (int)stats.qual.qual << " " << (int)range.max_qual.qual << " " << (int)range.avg_qual.qual<< std::endl;
-        quality=100*stats.qual.qual/maxQuality;
         signal=stats.qual.level;
         noise=stats.qual.noise;
+        maxQuality=range.max_qual.qual;
+
+        if (maxQuality<=0 || maxQuality>100) {
+          maxQuality=0;
+          quality=GetQualityFromSignalNoiseDbm(signal-0x100,noise-0x100);
+        }
+        else {
+          quality=100*stats.qual.qual/maxQuality;
+        }
+      }
+      else {
+        std::cerr << "Quality not set in stats" << std::endl;
       }
     }
+    else {
+      std::cerr << "Cannot read interface stats: " << strerror(errno) << std::endl;
+    }
+  }
+  else {
+    std::cerr << "Cannot read interface value ranges: " << strerror(errno) << std::endl;
   }
 
   memset(&data,0,sizeof(struct iwreq));
@@ -221,6 +237,8 @@ bool StatusLinux::UpdateNetworks()
   struct ifreq         ifr;
   struct iwreq         data;
 
+  Lum::OS::Guard<Lum::OS::Mutex> guard(mutex);
+
   networks.clear();
 
   file.open("/proc/net/wireless",std::ios::in);
