@@ -53,6 +53,8 @@
   #include "StatusNone.h"
 #endif
 
+#define NETWORK_REFRESH 10
+
 #include <iostream>
 static Lum::AppInfo info;
 
@@ -110,12 +112,16 @@ private:
   {
     Lum::OS::display->RemoveTimer(networksTimer);
 
-    if (status.SupportsNetworkRetrieval() && !status.UpdateNetworks()) {
-      tableModel->Clear();
-      UpdateNetworks();
+    if (status.SupportsNetworkRetrieval()) {
+      if (status.UpdateNetworks()) {
+        UpdateNetworks();
+      }
+      else {
+        tableModel->Clear();
+      }
     }
 
-    Lum::OS::display->AddTimer(refreshTime->Get(),0,networksTimer);
+    Lum::OS::display->AddTimer(NETWORK_REFRESH,0,networksTimer);
   }
 
   void UpdateStatus()
@@ -230,7 +236,7 @@ private:
         Lum::Model::ListTable::StdEntry *entry;
 
         gauge=new Lum::FuelGauge();
-        gauge->SetFlex(true,true);
+        gauge->SetFlex(true,false);
         //gauge->SetMinWidth(Lum::Base::Size::stdCharWidth,30);
 
         data=new Lum::Model::Double();
@@ -292,14 +298,14 @@ public:
     quality->SetRange(0,100);
     refreshTime->SetRange(0,10);
 
-    AttachModel(refreshTime);
-    AttachModel(statusTimer);
-    AttachModel(networksTimer);
-    AttachModel(GetOpenedAction());
-    AttachModel(aboutAction);
+    Observe(refreshTime);
+    Observe(statusTimer);
+    Observe(networksTimer);
+    Observe(GetOpenedAction());
+    Observe(aboutAction);
 
-    AttachModel(status.statusChangedAction);
-    AttachModel(status.networksChangedAction);
+    Observe(status.statusChangedAction);
+    Observe(status.networksChangedAction);
   }
 
   virtual void PreInit()
